/*
 * Copyright 2004 Sun Microsystems, Inc. All rights reserved.
 * SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;
import javax.xml.bind.PropertyException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;

import com.ssb.gcms.gaa.accountmaintenance.jaxb.request.impl.NamespacePrefixMapperImpl;
import com.sun.org.apache.xerces.internal.parsers.DOMParser;


/**
 * This example shows you how you can change the way
 * the marshaller assigns prefixes to namespace URIs.
 *
 * @author
 *     Kohsuke Kawaguchi (kohsuke.kawaguchi@sun.com)
 */
public class PrefixExample {

    public static void main( String[] args ) {

	try{

		test(args[0]);//xml file name to be passed

	}catch(Exception e)
		e.printStackTrace();
    }

    public static Element test( String fileName ) throws Exception {

	   JAXBContext context = JAXBContext.newInstance("com.ssb.gcms.gaa.accountmaintenance.jaxb.request");

        // unmarshal a file specified by the command line argument
        Object o = context.createUnmarshaller().unmarshal(new File(fileName));
		System.out.println("Unmarshalled  Object "+o.getClass().getName());
        Marshaller marshaller = context.createMarshaller();

        // to specify the URI->prefix mapping, you'll need to provide an
        // implementation of NamespaecPrefixMapper, which determines the
        // prefixes used for marshalling.
        //
        // you specify this as a property of Marshaller to
        // tell the marshaller to consult your mapper
        // to assign a prefix for a namespace.
        try {

            marshaller.setProperty("com.sun.xml.bind.namespacePrefixMapper",new NamespacePrefixMapperImpl());

        } catch( PropertyException e ) {
//            // if the JAXB provider doesn't recognize the prefix mapper,
//            // it will throw this exception. Since being unable to specify
//            // a human friendly prefix is not really a fatal problem,
//            // you can just continue marshalling without failing
//            ;
        }

        // make the output indented. It looks nicer on screen.
        // this is a JAXB standard property, so it should work with any JAXB impl.
        marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT,Boolean.TRUE);

        // print it out to the console since we are just testing the behavior.
        //Writer pr=new BufferedWriter(new PrintWriter(System.out));
		ByteArrayOutputStream stream=new ByteArrayOutputStream();
		marshaller.marshal(o,stream);
		String xmlStr=new String(stream.toByteArray());


		System.out.println("xmlStr--->"+xmlStr);

		DOMParser parser=new DOMParser();
		System.out.println("Parsing.............");
		parser.parse(new InputSource(new ByteArrayInputStream(stream.toByteArray())));
		System.out.println("Getting Doc.............");
		Document doc=parser.getDocument();


        Element element=doc.getDocumentElement();

        return element;
    }
}
